summaryrefslogtreecommitdiffstats
path: root/perl-install/bootloader.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/bootloader.pm')
-rw-r--r--perl-install/bootloader.pm14
1 files changed, 7 insertions, 7 deletions
diff --git a/perl-install/bootloader.pm b/perl-install/bootloader.pm
index 30d3964fe..9fd22112e 100644
--- a/perl-install/bootloader.pm
+++ b/perl-install/bootloader.pm
@@ -193,9 +193,9 @@ sub add_kernel {
$ext = "-$version";
}
# If itanium architecture store kernel & initrd in /boot/efi
if (arch() =~ /ia64/) {
- $boot="/boot/efi";
+ $boot="/boot/efi/mandrake";
}
log::l("adding vmlinuz$ext as vmlinuz-$version");
@@ -283,7 +283,7 @@ sub configure_entry {
my $boot="/boot/";
if (arch() =~ /ia64/) {
- $boot="/boot/efi";
+ $boot="/boot/efi/mandrake";
}
$entry->{kernel_or_dev} =~ /vmlinu.-(.*)/ and $specific_version = $1;
@@ -308,7 +308,7 @@ sub dev2prompath { #- SPARC only
sub get_kernels_and_labels() {
my $dir = "$::prefix/boot";
if ( arch() =~ /ia64/ ) {
- $dir = "$::prefix/boot/efi"; }
+ $dir = "$::prefix/boot/efi/mandrake"; }
my @l = grep { /^vmlinuz-/ } all($dir);
my @kernels = grep { ! -l "$dir/$_" } @l;
@@ -819,7 +819,7 @@ sub write_lilo_conf {
{
local *F;
local $\ = "\n";
- my $f = arch() =~ /ia64/ ? "$::prefix/boot/efi/elilo.conf" : "$::prefix/etc/lilo.conf";
+ my $f = arch() =~ /ia64/ ? "$::prefix/boot/efi/mandrake/elilo.conf" : "$::prefix/etc/lilo.conf";
open F, ">$f" or die "cannot create lilo config file: $f";
log::l("writing lilo config to $f");
@@ -899,14 +899,14 @@ sub write_elilo_conf {
my $file2fullname = sub {
my ($file) = @_;
- $file =~ s|/boot/efi/||;
+ $file =~ s|/boot/efi/mandrake/||;
$file
};
{
local *F;
local $\ = "\n";
- my $f = "$prefix/boot/efi/elilo.conf";
+ my $f = "$prefix/boot/efi/mandrake/elilo.conf";
open F, ">$f" or die "cannot create lilo config file: $f";
log::l("writing elilo config to $f");
@@ -193,9 +193,9 @@ sub add_kernel {
$ext = "-$version";
}
- # If itanium architecture store kernel & initrd in /boot/efi
+ # If itanium architecture store kernel & initrd in /boot/efi/mandrake
if (arch() =~ /ia64/) {